.left margin
.ifnot hlp
.hl 1 Page Headers
The page header consists of a title and subtitle printed at the top of each
page, as well as a page number.  This title is printed on the first line
below the top margin, and the subtitle on the next line.  The page number
will normally appear right justified on the same line with the title.
.ifnot small
The page number is normally preceded by the word "Page".
The title and subtitle are normally left justified.  The actual location
of title, subtitle, and page number are controlled by the _.LAYOUT command.
In addition to the following commands, the _.NUMBER PAGE, _.DISPLAY NUMBER
 _.NO NUMBER, and _.NO NUMBER CHAPTER commands control the page header.
.s 2
.endif small
.endif hlp
.helpc TITLE
.q _.TITLE [;][text] 
.qq _.T [;][text] 
.qn _.NO TITLE 
.x NO>TITLE 
.p.x TITLE  
break the text and set the title for the top of the page.
.ifnot small
_.TITLE takes the remaining text as the title and outputs it on every page at
line 0. The title is normally left justified with respect to the permanent
left margin.  See the _.PAGE SIZE command. The permanent margins allow
different margins for the headers than for the text. Titles are also produced
by these commands: _.FIRST TITLE, _.CHAPTER, or _.APPENDIX. Titles can contain
any special characters, but autoindexing will not work and tabs are converted
to spaces. Normally only the flags enabled at the last _.TITLE or _.SUBTITLE
command will be used in producing the title/subtitle.  If you wish to control
the flags, use the _.SAVE HEADER command.  If a flag is specified or removed
with a _.FLAGS command, all subsequent titles and subtitles will be affected. 
.p
_.NO TITLE inhibits printing of either the title or the subtitle at the top
of the page. Title printing is reinstated by the _.TITLE command. 
.i5;(The optional [;] is not used in DSR)

.if hlp
.if rsx .i5;Further help: FIRST
.endif rsx
.endif hlp
.helpd FIRST
.endif small
.q _.FIRST TITLE  [;][text]
.qq _.FT  [;][text]
.p.x FIRST TITLE  
is similar to _.TITLE, but is used to specify the title to be printed on the
first page of the document.  This command must precede all text in the
source file.  Use of the FIRST TITLE command is the only way to print a
title line on the first page of the document. 
.ifnot small
If the page number is formatted to appear on the same line as the title,
it will not appear on the first page unless a _.FIRST TITLE command is
issued.  If the title is blank, only the page number will be printed. If the
page number is at the bottom of the page, it will be printed on the first page
whether or not a _.FIRST TITLE command is used. The _.FIRST TITLE command
is equivalent to:
.i+5;_.HEADERS _.TITLE [ text ]
.s;(DSR doesn't support any parameters after _.FIRST TITLE. If you wish to
use this command in the same way as DSR, include a _.TITLE command on the
line after _.FIRST TITLE.)
.endif small
.helpc SUBTITLE
.q _.SUBTITLE [;][text] 
.qq _.ST [;][text]
.p.x SUBTITLE  
specifies the text to be used as the subtitle that appears directly under
the title.
.ifnot small
The subtitle is aligned on the same margin as the title.
The subtitle is not printed if the _.NO TITLE command is in force.
If you do not wish to have a subtitle, use the _.SUBTITLE command without
any text. 
.i5;(The optional [;] is not used in DSR)
.endif small
.helpc LAYOUT
.q _.LAYOUT [code] [,spacing]
.qq _.LO [code] [,spacing]
.p.x LAYOUT
breaks the current line and changes the layout of the title and page numbers
on the page. 
.ifnot small
This command does not have any affect on the current page.  The next page will
have the new layout. If you want to change only the first page of each
chapter, use the _.CHAPTER LAYOUT command.
The spacing is the number of blank lines between the last line on the page
and the page number.
If the code is 0, then the spacing is the number of blank lines minus 1
between the bottom of the text and the bottom of the page.
Pages with different layouts but the same spacing will have the same number
of lines on a page regardless of whether the page number is at the top or
bottom of the page. If the spacing is omitted, it is assumed to be 2 except
for code 0. For code 0, it is assumed to be -1 if not specified.
If layout 0 is used, the first page of a document will not have a page number
unless _.FIRST TITLE or _.HEADERS commands are used at the beginning.
However, all other layouts will number every page.
This is consistent with DSR usage. The layout codes are: 
.s

.if hlp
.if rsx ;ADDITIONAL HELP AVAILABLE: code CHAPTER
.endif rsx
.endif hlp
.HELPD CODE
.endif small
.ts +6,+10,+10,+10
.lm +6
.i-6; ^&CODE	PAGE LAYOUT\&
.i-6; 0	Title flush left, page number flush right
.i-6; 1	Title center ,number bottom center
.i-6; 2	Title right odd page/left even ,number bottom center
.i-6; 3	Title left, number bottom center
.i-6; 4	Title left, number bottom right
.i-6; 5	Title center, number bottom right
.i-6; 6	Title center, number bottom right odd/left even
.i-6; 7	Title top, number bottom, both right odd/left even
.i-6; 8	Title left, number right odd/left even
.i-6; 9	Title right odd/left even, number bottom right
.i-6;10	Title center, number bottom left
.i-6;11	Title right odd/left even, number bottom left
.i-6;12	Title left, number bottom left
.i-6;13	Title right, number bottom left
.i-6;14	Title right, number bottom center
.i-6;15	Title right, number bottom right odd/left even
.i-6;16	Title right, number bottom right
.lm-6
.ifnot small
.i5;DEFAULT: _.LAYOUT 0
.i5;(Codes 5-16 not available in DSR)
.helpd CHAPTER
.endif small
.q _.CHAPTER LAYOUT [code] [,spacing]
.qq _.CHLO [code] [,spacing]
.p.x CHAPTER LAYOUT
changes the layout for the first page of a chapter or appendix
without having any effect on other pages.  
.ifnot small
The parameters are specified in
the same manner as for the _.LAYOUT command. If this command is not used, or
used with no parameters, the layout will be the same for
all pages of a document. 
.i5;(Not available in DSR)
.endif small
.helpc HEADERS
.q _.HEADERS [on]
.qq _.HD [on]
.qn _.NO HEADERS [on]
.qn _.NHD
.x NO>HEADERS
.p.x HEADERS
control whether the page header (title, subtitle, and page number) is
printed. 
.ifnot small
If a layout other than 0 is used, the page number is still printed at the
bottom of the page and only the title and subtitle can be suppressed. If the
header lines are disabled, the text begins at the top margin where the header
would normally start.  The first page of output from RUNOFF is formatted as if
the   _.NO HEADERS command had been issued, while subsequent pages are
formatted as if the _.HEADERS command had been issued.  This can be changed by
issuing the _.FIRST TITLE command before any text on the first page. 
.if not hlp
.q _.HEADERS PAGE 
.qn _.HEADERS NO PAGE 
.x HEADERS > NO PAGE 
.p.x HEADERS >PAGE 
controls whether RUNOFF prints the word PAGE in front of the page number.
This command is equivalent to _.DISPLAY NUMBER "PAGE ".
.i5;DEFAULT: _.HEADERS PAGE
.i5;(Not available in DSR)
.q _.HEADERS UPPER
.x HEADERS > UPPER
.qq _.HEADERS MIXED 
.x HEADERS > MIXED 
.qq _.HEADERS LOWER 
.p.x HEADERS > LOWER 
enables the header and specifies the format of the pre-header.
UPPER, MIXED or LOWER cause the word "PAGE" to be printed
before the page number in all upper case, capitalized, or all lower case
respectively.
.end text
.note
The _.DISPLAY NUMBER command should be used rather than _.HEADERS UPPER
 _.HEADERS LOWER, _.HEADERS MIXED, _.HEADERS NO PAGE, and _.HEADERS PAGE.
It is a more versatile command and it can perform all the same functions
of these other HEADERS commands.
.end note
.endif hlp
.if hlp
.if rsx .i5;ADDITIONAL HELP AVAILABLE: SPACING
.endif rsx
.endif hlp
.helpd SPACING
.endif small
.q _.HEADERS SPACING [n]
.qq _.HDSP [n]
.p.x HEADERS>SPACING
sets the spacing between the title and the first line of text.  The value 
n is the number of lines to skip.  If n is not specified, the current 
spacing per line of text is used as the default.  
The minimum value for n is 1. If 0 is specified, the value of 1 is assumed. 
.i5;DEFAULT: _.HEADER SPACING 3
.i5;(Not available in DSR)
.end text
